.. _Model:

patito.Model
============

.. currentmodule:: patito

.. autoclass:: Model

.. toctree::
   :caption: Class methods & properties
   :maxdepth: 1

   DataFrame <DataFrame>
   LazyFrame <LazyFrame>
   columns <columns>
   defaults <defaults>
   drop <drop>
   dtypes <dtypes>
   example <example>
   example_value <example_value>
   examples <examples>
   from_row <from_row>
   iter_models <iter_models>
   join <join>
   non_nullable_columns <non_nullable_columns>
   nullable_columns <nullable_columns>
   pandas_examples <pandas_examples>
   prefix <prefix>
   rename <rename>
   select <select>
   suffix <suffix>
   unique_columns <unique_columns>
   valid_dtypes <valid_dtypes>
   validate <validate>
   with_fields <with_fields>
